@@ -18,6 +18,7 @@ pub enum Clang {
     AccessSpecDecl(AccessSpecDecl),
     AliasAttr(AliasAttr),
     AlignedAttr(AlignedAttr),
+    AllocAlignAttr(AllocAlignAttr),
     AllocSizeAttr(AllocSizeAttr),
     AlwaysInlineAttr(AlwaysInlineAttr),
     ArrayInitIndexExpr(ArrayInitIndexExpr),
@@ -25,8 +26,15 @@ pub enum Clang {
     ArraySubscriptExpr(ArraySubscriptExpr),
     AsmLabelAttr(AsmLabelAttr),
     AtomicExpr(AtomicExpr),
+    AttributedStmt(AttributedStmt),
+    AttributedType(AttributedType),
+    AutoType(AutoType),
+    AvailabilityAttr(AvailabilityAttr),
     BinaryOperator(BinaryOperator),
+    BindingDecl(BindingDecl),
+    BlockPointerType(BlockPointerType),
     BreakStmt(BreakStmt),
+    BuiltinBitCastExpr(BuiltinBitCastExpr),
     BuiltinTemplateDecl(BuiltinTemplateDecl),
     BuiltinType(BuiltinType),
     CStyleCastExpr(CStyleCastExpr),
@@ -39,12 +47,14 @@ pub enum Clang {
     CXXConstructorDecl(CXXConstructorDecl),
     CXXConversionDecl(CXXConversionDecl),
     CXXCtorInitializer(CXXCtorInitializer),
+    CXXDeductionGuideDecl(CXXDeductionGuideDecl),
     CXXDefaultArgExpr(CXXDefaultArgExpr),
     CXXDefaultInitExpr(CXXDefaultInitExpr),
     CXXDeleteExpr(CXXDeleteExpr),
     CXXDependentScopeMemberExpr(CXXDependentScopeMemberExpr),
     CXXDestructorDecl(CXXDestructorDecl),
     CXXDynamicCastExpr(CXXDynamicCastExpr),
+    CXXFoldExpr(CXXFoldExpr),
     CXXForRangeStmt(CXXForRangeStmt),
     CXXFunctionalCastExpr(CXXFunctionalCastExpr),
     CXXInheritedCtorInitExpr(CXXInheritedCtorInitExpr),
@@ -57,6 +67,7 @@ pub enum Clang {
     CXXPseudoDestructorExpr(CXXPseudoDestructorExpr),
     CXXRecordDecl(CXXRecordDecl),
     CXXReinterpretCastExpr(CXXReinterpretCastExpr),
+    CXXRewrittenBinaryOperator(CXXRewrittenBinaryOperator),
     CXXScalarValueInitExpr(CXXScalarValueInitExpr),
     CXXStaticCastExpr(CXXStaticCastExpr),
     CXXTemporaryObjectExpr(CXXTemporaryObjectExpr),
@@ -72,31 +83,40 @@ pub enum Clang {
     ClassTemplateDecl(ClassTemplateDecl),
     ClassTemplatePartialSpecializationDecl(ClassTemplatePartialSpecializationDecl),
     ClassTemplateSpecializationDecl(ClassTemplateSpecializationDecl),
+    ColdAttr(ColdAttr),
     ComplexType(ComplexType),
     CompoundAssignOperator(CompoundAssignOperator),
     CompoundStmt(CompoundStmt),
+    ConceptDecl(ConceptDecl),
+    ConceptSpecializationExpr(ConceptSpecializationExpr),
     ConditionalOperator(ConditionalOperator),
     ConstAttr(ConstAttr),
     ConstantArrayType(ConstantArrayType),
     ConstantExpr(ConstantExpr),
     ConstructorUsingShadowDecl(ConstructorUsingShadowDecl),
     ContinueStmt(ContinueStmt),
+    DLLImportAttr(DLLImportAttr),
     DeclRefExpr(DeclRefExpr),
     DeclStmt(DeclStmt),
     DecltypeType(DecltypeType),
+    DecompositionDecl(DecompositionDecl),
     DefaultStmt(DefaultStmt),
     DependentNameType(DependentNameType),
     DependentScopeDeclRefExpr(DependentScopeDeclRefExpr),
     DependentSizedArrayType(DependentSizedArrayType),
     DependentTemplateSpecializationType(DependentTemplateSpecializationType),
     DeprecatedAttr(DeprecatedAttr),
+    DiagnoseIfAttr(DiagnoseIfAttr),
+    DisableTailCallsAttr(DisableTailCallsAttr),
     DoStmt(DoStmt),
     ElaboratedType(ElaboratedType),
     EmptyDecl(EmptyDecl),
+    EnableIfAttr(EnableIfAttr),
     EnumConstantDecl(EnumConstantDecl),
     EnumDecl(EnumDecl),
     EnumType(EnumType),
     ExprWithCleanups(ExprWithCleanups),
+    FallThroughAttr(FallThroughAttr),
     FieldDecl(FieldDecl),
     FinalAttr(FinalAttr),
     FloatingLiteral(FloatingLiteral),
@@ -107,7 +127,10 @@ pub enum Clang {
     FunctionDecl(FunctionDecl),
     FunctionProtoType(FunctionProtoType),
     FunctionTemplateDecl(FunctionTemplateDecl),
+    GCCAsmStmt(GCCAsmStmt),
+    GNUInlineAttr(GNUInlineAttr),
     GNUNullExpr(GNUNullExpr),
+    GotoStmt(GotoStmt),
     IfStmt(IfStmt),
     ImplicitCastExpr(ImplicitCastExpr),
     ImplicitValueInitExpr(ImplicitValueInitExpr),
@@ -116,15 +139,22 @@ pub enum Clang {
     InitListExpr(InitListExpr),
     InjectedClassNameType(InjectedClassNameType),
     IntegerLiteral(IntegerLiteral),
+    InternalLinkageAttr(InternalLinkageAttr),
     LValueReferenceType(LValueReferenceType),
+    LabelStmt(LabelStmt),
     LambdaExpr(LambdaExpr),
     LinkageSpecDecl(LinkageSpecDecl),
     MaterializeTemporaryExpr(MaterializeTemporaryExpr),
+    MaxFieldAlignmentAttr(MaxFieldAlignmentAttr),
     MayAliasAttr(MayAliasAttr),
     MemberExpr(MemberExpr),
     MemberPointerType(MemberPointerType),
     ModeAttr(ModeAttr),
+    NamespaceAliasDecl(NamespaceAliasDecl),
     NamespaceDecl(NamespaceDecl),
+    NoDebugAttr(NoDebugAttr),
+    NoEscapeAttr(NoEscapeAttr),
+    NoSanitizeAttr(NoSanitizeAttr),
     NoThrowAttr(NoThrowAttr),
     NoUniqueAddressAttr(NoUniqueAddressAttr),
     NonNullAttr(NonNullAttr),
@@ -146,6 +176,7 @@ pub enum Clang {
     QualType(QualType),
     RValueReferenceType(RValueReferenceType),
     RecordType(RecordType),
+    RequiresExpr(RequiresExpr),
     RestrictAttr(RestrictAttr),
     ReturnStmt(ReturnStmt),
     ReturnsNonNullAttr(ReturnsNonNullAttr),
@@ -166,6 +197,7 @@ pub enum Clang {
     TypeAliasTemplateDecl(TypeAliasTemplateDecl),
     TypeOfExprType(TypeOfExprType),
     TypeTraitExpr(TypeTraitExpr),
+    TypeVisibilityAttr(TypeVisibilityAttr),
     TypedefDecl(TypedefDecl),
     TypedefType(TypedefType),
     UnaryExprOrTypeTraitExpr(UnaryExprOrTypeTraitExpr),
@@ -173,6 +205,7 @@ pub enum Clang {
     UnaryTransformType(UnaryTransformType),
     UnresolvedLookupExpr(UnresolvedLookupExpr),
     UnresolvedMemberExpr(UnresolvedMemberExpr),
+    UnresolvedUsingTypenameDecl(UnresolvedUsingTypenameDecl),
     UnresolvedUsingValueDecl(UnresolvedUsingValueDecl),
     UnusedAttr(UnusedAttr),
     UsingDecl(UsingDecl),
@@ -180,9 +213,11 @@ pub enum Clang {
     UsingShadowDecl(UsingShadowDecl),
     VarDecl(VarDecl),
     VarTemplateDecl(VarTemplateDecl),
+    VarTemplatePartialSpecializationDecl(VarTemplatePartialSpecializationDecl),
     VarTemplateSpecializationDecl(VarTemplateSpecializationDecl),
     VisibilityAttr(VisibilityAttr),
     WarnUnusedResultAttr(WarnUnusedResultAttr),
+    WeakImportAttr(WeakImportAttr),
     WeakRefAttr(WeakRefAttr),
     WhileStmt(WhileStmt),
     #[serde(rename = "null")]
@@ -219,6 +254,17 @@ pub struct AlignedAttr {
     pub range: SourceRange,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct AllocAlignAttr {
+    pub range: SourceRange,
+    #[serde(default)]
+    pub inherited: bool,
+    #[serde(default)]
+    pub implicit: bool,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -284,6 +330,37 @@ pub struct AtomicExpr {
     pub value_category: ValueCategory,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct AttributedStmt {
+    pub range: SourceRange,
+}
+
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct AttributedType {
+    pub r#type: Type,
+}
+
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct AutoType {
+    pub r#type: Type,
+    pub undeduced: bool,
+    #[serde(rename = "typeKeyword")]
+    pub type_keyword: AutoTypeKeyword,
+}
+
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct AvailabilityAttr {
+    pub range: SourceRange,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -295,6 +372,28 @@ pub struct BinaryOperator {
     pub opcode: BinaryOpcode,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct BindingDecl {
+    pub loc: SourceLocation,
+    pub range: SourceRange,
+    #[serde(rename = "isReferenced", default)]
+    pub is_referenced: bool,
+    name: Box<str>,
+}
+
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct BlockPointerType {
+    pub r#type: Type,
+    #[serde(rename = "isDependent", default)]
+    pub is_dependent: bool,
+    #[serde(rename = "isInstantiationDependent", default)]
+    pub is_instantiation_dependent: bool,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -302,6 +401,18 @@ pub struct BreakStmt {
     pub range: SourceRange,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct BuiltinBitCastExpr {
+    pub range: SourceRange,
+    pub r#type: Type,
+    #[serde(rename = "valueCategory")]
+    pub value_category: ValueCategory,
+    #[serde(rename = "castKind")]
+    pub cast_kind: CastKind,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -337,6 +448,8 @@ pub struct CStyleCastExpr {
 #[non_exhaustive]
 pub struct CXX11NoReturnAttr {
     pub range: SourceRange,
+    #[serde(default)]
+    pub inherited: bool,
 }
 
 #[derive(Deserialize, Debug)]
@@ -433,6 +546,8 @@ pub struct CXXConstructorDecl {
     pub explicitly_deleted: bool,
     #[serde(default)]
     pub constexpr: bool,
+    #[serde(default)]
+    pub variadic: bool,
     #[serde(rename = "explicitlyDefaulted", default)]
     pub explicitly_defaulted: ExplicitlyDefaulted,
 }
@@ -447,6 +562,8 @@ pub struct CXXConversionDecl {
     pub is_implicit: bool,
     #[serde(rename = "isUsed", default)]
     pub is_used: bool,
+    #[serde(rename = "isReferenced", default)]
+    pub is_referenced: bool,
     #[serde(rename = "parentDeclContextId")]
     pub parent_decl_context_id: Option<Id>,
     #[serde(rename = "previousDecl")]
@@ -472,6 +589,22 @@ pub enum CXXCtorInitializer {
     DelegatingInitializer(Type),
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct CXXDeductionGuideDecl {
+    pub loc: SourceLocation,
+    pub range: SourceRange,
+    #[serde(rename = "isImplicit", default)]
+    pub is_implicit: bool,
+    #[serde(rename = "isUsed", default)]
+    pub is_used: bool,
+    pub name: Box<str>,
+    #[serde(rename = "mangledName")]
+    pub mangled_name: Option<Box<str>>,
+    pub r#type: Type,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -555,6 +688,8 @@ pub struct CXXDestructorDecl {
     pub r#virtual: bool,
     #[serde(rename = "explicitlyDeleted", default)]
     pub explicitly_deleted: bool,
+    #[serde(default)]
+    pub constexpr: bool,
     #[serde(rename = "explicitlyDefaulted", default)]
     pub explicitly_defaulted: ExplicitlyDefaulted,
 }
@@ -571,6 +706,16 @@ pub struct CXXDynamicCastExpr {
     pub cast_kind: CastKind,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct CXXFoldExpr {
+    pub range: SourceRange,
+    pub r#type: Type,
+    #[serde(rename = "valueCategory")]
+    pub value_category: ValueCategory,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -952,6 +1097,13 @@ pub struct ClassTemplateSpecializationDecl {
     pub bases: Vec<CXXBaseSpecifier>,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct ColdAttr {
+    pub range: SourceRange,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -981,6 +1133,25 @@ pub struct CompoundStmt {
     pub range: SourceRange,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct ConceptDecl {
+    pub loc: SourceLocation,
+    pub range: SourceRange,
+    pub name: Box<str>,
+}
+
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct ConceptSpecializationExpr {
+    pub range: SourceRange,
+    pub r#type: Type,
+    #[serde(rename = "valueCategory")]
+    pub value_category: ValueCategory,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -1041,6 +1212,13 @@ pub struct ContinueStmt {
     pub range: SourceRange,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct DLLImportAttr {
+    pub range: SourceRange,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -1073,6 +1251,19 @@ pub struct DecltypeType {
     pub is_dependent: bool,
     #[serde(rename = "isInstantiationDependent", default)]
     pub is_instantiation_dependent: bool,
+    #[serde(rename = "containsUnexpandedPack", default)]
+    pub contains_unexpanded_pack: bool,
+}
+
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct DecompositionDecl {
+    pub loc: SourceLocation,
+    pub range: SourceRange,
+    pub r#type: Type,
+    #[serde(default)]
+    pub init: InitStyle,
 }
 
 #[derive(Deserialize, Debug)]
@@ -1132,6 +1323,22 @@ pub struct DependentTemplateSpecializationType {
 #[non_exhaustive]
 pub struct DeprecatedAttr {
     pub range: SourceRange,
+    #[serde(default)]
+    pub inherited: bool,
+}
+
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct DiagnoseIfAttr {
+    pub range: SourceRange,
+}
+
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct DisableTailCallsAttr {
+    pub range: SourceRange,
 }
 
 #[derive(Deserialize, Debug)]
@@ -1150,6 +1357,8 @@ pub struct ElaboratedType {
     pub is_dependent: bool,
     #[serde(rename = "isInstantiationDependent", default)]
     pub is_instantiation_dependent: bool,
+    #[serde(rename = "containsUnexpandedPack", default)]
+    pub contains_unexpanded_pack: bool,
     pub qualifier: Option<Box<str>>,
     #[serde(rename = "ownedTagDecl")]
     pub owned_tag_decl: Option<Decl>,
@@ -1163,6 +1372,13 @@ pub struct EmptyDecl {
     pub range: SourceRange,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct EnableIfAttr {
+    pub range: SourceRange,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -1183,6 +1399,8 @@ pub struct EnumDecl {
     pub range: SourceRange,
     #[serde(rename = "isReferenced", default)]
     pub is_referenced: bool,
+    #[serde(rename = "previousDecl")]
+    pub previous_decl: Option<Id>,
     pub name: Option<Box<str>>,
     #[serde(rename = "fixedUnderlyingType")]
     pub fixed_underlying_type: Option<Type>,
@@ -1210,6 +1428,13 @@ pub struct ExprWithCleanups {
     pub cleanups_have_side_effects: bool,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct FallThroughAttr {
+    pub range: SourceRange,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -1338,6 +1563,12 @@ pub struct FunctionProtoType {
     pub variadic: bool,
     #[serde(rename = "refQualifier", default)]
     pub ref_qualifier: RefQualifier,
+    #[serde(rename = "exceptionSpec", default)]
+    pub exception_spec: ExceptionSpec,
+    #[serde(rename = "exceptionTypes", default)]
+    pub exception_types: Vec<Type>,
+    #[serde(rename = "conditionEvaluatesTo")]
+    pub condition_evaluates_to: Option<bool>,
     pub r#type: Type,
     #[serde(rename = "isDependent", default)]
     pub is_dependent: bool,
@@ -1354,6 +1585,8 @@ pub struct FunctionTemplateDecl {
     pub loc: SourceLocation,
     #[serde(default)]
     pub range: SourceRange,
+    #[serde(rename = "isImplicit", default)]
+    pub is_implicit: bool,
     #[serde(rename = "parentDeclContextId")]
     pub parent_decl_context_id: Option<Id>,
     #[serde(rename = "previousDecl")]
@@ -1361,6 +1594,20 @@ pub struct FunctionTemplateDecl {
     pub name: Box<str>,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct GCCAsmStmt {
+    pub range: SourceRange,
+}
+
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct GNUInlineAttr {
+    pub range: SourceRange,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -1371,6 +1618,15 @@ pub struct GNUNullExpr {
     pub value_category: ValueCategory,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct GotoStmt {
+    pub range: SourceRange,
+    #[serde(rename = "targetLabelDeclId")]
+    pub target_label_decl_id: Id,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -1472,6 +1728,15 @@ pub struct IntegerLiteral {
     pub value: Box<str>,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct InternalLinkageAttr {
+    pub range: SourceRange,
+    #[serde(default)]
+    pub inherited: bool,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -1483,6 +1748,16 @@ pub struct LValueReferenceType {
     pub is_instantiation_dependent: bool,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct LabelStmt {
+    pub range: SourceRange,
+    pub name: Box<str>,
+    #[serde(rename = "declId")]
+    pub decl_id: Id,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -1522,6 +1797,15 @@ pub struct MaterializeTemporaryExpr {
     pub bound_to_lvalue_ref: bool,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct MaxFieldAlignmentAttr {
+    pub range: SourceRange,
+    #[serde(default)]
+    pub implicit: bool,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -1568,6 +1852,17 @@ pub struct ModeAttr {
     pub range: SourceRange,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct NamespaceAliasDecl {
+    pub loc: SourceLocation,
+    pub range: SourceRange,
+    pub name: Box<str>,
+    #[serde(rename = "aliasedNamespace")]
+    pub aliased_namespace: Decl,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -1583,6 +1878,29 @@ pub struct NamespaceDecl {
     pub original_namespace: Option<Decl>,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct NoDebugAttr {
+    pub range: SourceRange,
+}
+
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct NoEscapeAttr {
+    pub range: SourceRange,
+}
+
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct NoSanitizeAttr {
+    pub range: SourceRange,
+    #[serde(default)]
+    pub inherited: bool,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -1814,6 +2132,16 @@ pub struct RecordType {
     pub decl: Decl,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct RequiresExpr {
+    pub range: SourceRange,
+    pub r#type: Type,
+    #[serde(rename = "valueCategory")]
+    pub value_category: ValueCategory,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -1901,6 +2229,8 @@ pub struct SubstTemplateTypeParmType {
     pub is_dependent: bool,
     #[serde(rename = "isInstantiationDependent", default)]
     pub is_instantiation_dependent: bool,
+    #[serde(rename = "containsUnexpandedPack", default)]
+    pub contains_unexpanded_pack: bool,
 }
 
 #[derive(Deserialize, Debug)]
@@ -2052,6 +2382,15 @@ pub struct TypeTraitExpr {
     pub value_category: ValueCategory,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct TypeVisibilityAttr {
+    pub range: SourceRange,
+    #[serde(default)]
+    pub inherited: bool,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -2145,12 +2484,25 @@ pub struct UnresolvedMemberExpr {
     pub value_category: ValueCategory,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct UnresolvedUsingTypenameDecl {
+    pub loc: SourceLocation,
+    pub range: SourceRange,
+    #[serde(rename = "isReferenced", default)]
+    pub is_referenced: bool,
+    pub name: Box<str>,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
 pub struct UnresolvedUsingValueDecl {
-    pub loc: Option<SourceLocation>,
-    pub range: Option<SourceRange>,
+    #[serde(default)]
+    pub loc: SourceLocation,
+    #[serde(default)]
+    pub range: SourceRange,
     pub name: Box<str>,
     pub r#type: Option<Type>,
 }
@@ -2226,32 +2578,70 @@ pub struct VarDecl {
     #[serde(default)]
     pub nrvo: bool,
     #[serde(default)]
+    pub inline: bool,
+    #[serde(default)]
     pub constexpr: bool,
+    #[serde(rename = "modulePrivate", default)]
+    pub module_private: bool,
     #[serde(default)]
     pub init: InitStyle,
+    #[serde(rename = "isParameterPack", default)]
+    pub is_parameter_pack: bool,
 }
 
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
 pub struct VarTemplateDecl {
+    #[serde(default)]
     pub loc: SourceLocation,
+    #[serde(default)]
     pub range: SourceRange,
+    #[serde(rename = "previousDecl")]
+    pub previous_decl: Option<Id>,
     pub name: Box<str>,
 }
 
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
-pub struct VarTemplateSpecializationDecl {
+pub struct VarTemplatePartialSpecializationDecl {
     pub loc: SourceLocation,
     pub range: SourceRange,
-    #[serde(rename = "isUsed", default)]
-    pub is_used: bool,
+    #[serde(rename = "parentDeclContextId")]
+    pub parent_decl_context_id: Option<Id>,
     pub name: Box<str>,
     #[serde(rename = "mangledName")]
     pub mangled_name: Option<Box<str>>,
     pub r#type: Type,
+    #[serde(default)]
+    pub inline: bool,
+    #[serde(default)]
+    pub constexpr: bool,
+    pub init: InitStyle,
+}
+
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct VarTemplateSpecializationDecl {
+    #[serde(default)]
+    pub loc: SourceLocation,
+    #[serde(default)]
+    pub range: SourceRange,
+    #[serde(rename = "isUsed", default)]
+    pub is_used: bool,
+    #[serde(rename = "isReferenced", default)]
+    pub is_referenced: bool,
+    pub name: Box<str>,
+    #[serde(rename = "mangledName")]
+    pub mangled_name: Option<Box<str>>,
+    pub r#type: Type,
+    #[serde(default)]
+    pub inline: bool,
+    #[serde(default)]
+    pub constexpr: bool,
+    #[serde(default)]
     pub init: InitStyle,
 }
 
@@ -2273,6 +2663,13 @@ pub struct WarnUnusedResultAttr {
     pub range: SourceRange,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct WeakImportAttr {
+    pub range: SourceRange,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -2319,6 +2716,17 @@ impl Default for ArrayType {
     }
 }
 
+#[derive(Deserialize, Copy, Clone, Eq, PartialEq, Debug)]
+#[non_exhaustive]
+pub enum AutoTypeKeyword {
+    #[serde(rename = "auto")]
+    Auto,
+    #[serde(rename = "decltype(auto)")]
+    DecltypeAuto,
+    #[serde(rename = "__auto_type")]
+    GNUAutoType,
+}
+
 #[derive(Deserialize, Copy, Clone, Eq, PartialEq, Debug)]
 #[non_exhaustive]
 pub enum BinaryOpcode {
@@ -2798,7 +3206,7 @@ pub struct CXXBaseSpecifier {
 pub struct CXXRecordDefinitionData {
     #[serde(rename = "isGenericLambda", default)]
     pub is_generic_lambda: bool,
-    #[serde(rename = "isLamdba", default)]
+    #[serde(rename = "isLambda", default)]
     pub is_lambda: bool,
     #[serde(rename = "isEmpty", default)]
     pub is_empty: bool,
@@ -2843,6 +3251,16 @@ pub struct CXXRecordDefinitionData {
     pub dtor: DestructorDefinitionData,
 }
 
+#[derive(Deserialize, Debug)]
+#[serde(deny_unknown_fields)]
+#[non_exhaustive]
+pub struct CXXRewrittenBinaryOperator {
+    pub range: SourceRange,
+    pub r#type: Type,
+    #[serde(rename = "valueCategory")]
+    pub value_category: ValueCategory,
+}
+
 #[derive(Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 #[non_exhaustive]
@@ -2896,6 +3314,25 @@ pub struct DestructorDefinitionData {
     pub defaulted_is_deleted: bool,
 }
 
+#[derive(Deserialize, Copy, Clone, Eq, PartialEq, Debug)]
+#[non_exhaustive]
+pub enum ExceptionSpec {
+    #[serde(skip_deserializing)]
+    None,
+    #[serde(rename = "throw")]
+    Throw,
+    #[serde(rename = "noexcept")]
+    Noexcept,
+    #[serde(rename = "nothrow")]
+    Nothrow,
+}
+
+impl Default for ExceptionSpec {
+    fn default() -> Self {
+        ExceptionSpec::None
+    }
+}
+
 #[derive(Deserialize, Copy, Clone, Eq, PartialEq, Debug)]
 #[non_exhaustive]
 pub enum ExplicitlyDefaulted {
